package com.cpxt.biz.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cpxt.biz.domain.BizCarModel;

/**
 * 车型Service接口
 * 
 * @author YIN
 * @date 2024-12-16
 */
public interface IBizCarModelService 
{
    /**
     * 查询车型
     * 
     * @param id 车型主键
     * @return 车型
     */
    public BizCarModel selectBizCarModelById(Long id);

    /**
     * 查询车型列表
     *
     * @param bizCarModel 车型
     * @return 车型集合
     */
    public Page<BizCarModel> selectBizCarModelPage(BizCarModel bizCarModel,int pageNum, int pageSize);


    /**
     * 查询车型列表
     * 
     * @param bizCarModel 车型
     * @return 车型集合
     */
    public List<BizCarModel> selectBizCarModelList(BizCarModel bizCarModel);

    /**
     * 新增车型
     * 
     * @param bizCarModel 车型
     * @return 结果
     */
    public int insertBizCarModel(BizCarModel bizCarModel);

    /**
     * 修改车型
     * 
     * @param bizCarModel 车型
     * @return 结果
     */
    public int updateBizCarModel(BizCarModel bizCarModel);

    /**
     * 批量删除车型
     * 
     * @param ids 需要删除的车型主键集合
     * @return 结果
     */
    public int deleteBizCarModelByIds(Long[] ids);

    /**
     * 删除车型信息
     * 
     * @param id 车型主键
     * @return 结果
     */
    public int deleteBizCarModelById(Long id);
}
